==> haskell-hakyll-4.16.2.0-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.16.2.0
visibility:           public
id:                   hakyll-4.16.2.0-8AF19KoQKdV4fRPk8nsKlM
key:                  hakyll-4.16.2.0-8AF19KoQKdV4fRPk8nsKlM
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  a16553984f42d431bedd645f3c6a3ece
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hakyll-4.16.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hakyll-4.16.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hakyll-4.16.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.16.2.0-8AF19KoQKdV4fRPk8nsKlM
depends:
    aeson-2.1.2.1-5gViDrHjeNhDfT19MwgeMT base-4.17.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-1o80EWHMpY0BuGRIuRg92O
    blaze-markup-0.8.3.0-4zzXpVLD4d23Y4oP0TA1oB bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D
    deepseq-1.4.8.0 directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    fsnotify-0.4.2.0-ELwX7Rafx3THRO8QjB8zxp
    hashable-1.4.4.0-HcIU0jNirb1KY01FJoO6uU
    http-conduit-2.3.9.1-ESJQakueNx1GkZUuLxkDV0
    http-types-0.12.4-845zQBf8K2R8QZqh3scBqV
    lrucache-1.2.0.1-KqXn3rxkxjHdBTKj3hx2H mtl-2.2.2
    network-uri-2.6.4.2-9MIvjX5zY25ED43FJsYIB3
    optparse-applicative-0.18.1.0-7KCyXOPBHhG88hE75wN8Ie
    pandoc-3.1.12.1-JC42pvFy1wl3pdrGLLzFDv parsec-3.1.16.1
    process-1.6.18.0 random-1.2.1.3-2HbxmMbiRhQI1KxtG7s1TV
    regex-tdfa-1.3.2.4-4bEsOyd8ZjUKkdBbrZow28
    resourcet-1.2.6-60kBeMKLYLU7DGwHkUvFW1
    scientific-0.3.7.0-HvL2E1otFtODq1T2dktHha
    tagsoup-0.14.8-GVcETTo3uK139Ukym6PkKC template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-BooESfmG3DbHMU6mBvbzIL
    vector-0.13.2.0-InZif5xbqP17OkTvptfKiM
    wai-3.2.4-41iNGcJSwNvEUgUKaMQRRA
    wai-app-static-3.1.9-4NTdHTxjmfIGJ178lINDtN
    warp-3.3.30-KUCEwGn4TuyLVm9l2BLxF8
    yaml-0.11.11.2-2xyl6vgLYjLLxSjbPATLZ7

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.16.2.0-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.16.2.0
visibility:           public
id:                   hakyll-4.16.2.0-E9obAEt0lJP4lrO53mWkgJ
key:                  hakyll-4.16.2.0-E9obAEt0lJP4lrO53mWkgJ
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  9c366ed9af08526ce4c9912325cb12f3
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hakyll-4.16.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hakyll-4.16.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hakyll-4.16.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.16.2.0-E9obAEt0lJP4lrO53mWkgJ
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y base-4.17.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-Af5P3A2URAm8PEOIhy6b3k
    blaze-markup-0.8.3.0-Alr6JP17MQvDFN7aUk8LfK bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09
    deepseq-1.4.8.0 directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    fsnotify-0.4.2.0-24EbsOA8W2sJ4ow97u9QPi
    hashable-1.4.4.0-JPfSbBrFTKBgQKoWbpACz
    http-conduit-2.3.9.1-63uvzNDzBVvFQrib0s6jD5
    http-types-0.12.4-ERErpW4oIqaKIzWiLMLiFN
    lrucache-1.2.0.1-KqXn3rxkxjHdBTKj3hx2H mtl-2.2.2
    network-uri-2.6.4.2-9UqT53JjEGDF2lVDrQUMu1
    optparse-applicative-0.18.1.0-FC4zXF1Gvg5FVkM3KJzuj
    pandoc-3.1.12.1-KcGscjXpBBZLVANJlSdGNg parsec-3.1.16.1
    process-1.6.18.0 random-1.2.1.3-6Q31h3pRIgvDA2QDH6tJjk
    regex-tdfa-1.3.2.4-40KsSRk4M8NHq3ZFb3vbCq
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    scientific-0.3.7.0-H4Og6N92k1lGQSMIPZo0fR
    tagsoup-0.14.8-KVapG2hQFSRAmeRRQFLOow template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U
    wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    wai-app-static-3.1.9-EByFNLvVaiN3y9YxHfEcK7
    warp-3.3.30-4IsuVtgTa031VwzjyQOJNG
    yaml-0.11.11.2-GC1CtyXJHYx5kXLLIccvTD

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
